Module: Vertx::SSLSupport

Included in:
HttpClient
Defined in:
lib/vertx/ssl_support.rb

Overview

A mixin module allowing SSL attributes to be set on classes

Author:

Instance Method Summary collapse

Instance Method Details

#key_store_password(password = nil) ⇒ Object

Set or get key store password for fluent API



72
73
74
75
76
77
78
79
# File 'lib/vertx/ssl_support.rb', line 72

def key_store_password(password = nil)
  if password
    @j_del.setKeyStorePassword(password)
    self
  else
    @j_del.getKeyStorePassword
  end
end

#key_store_password=(val) ⇒ Object

Set the password for the SSL key store. This method should only be used with the client in SSL mode, i.e. after #ssl= has been set to true.

Parameters:

  • val. (String)

    The password.

Returns:

  • self. So multiple invocations can be chained.



66
67
68
69
# File 'lib/vertx/ssl_support.rb', line 66

def key_store_password=(val)
  @j_del.setKeyStorePassword(val)
  self
end

#key_store_path(path = nil) ⇒ Object

Set or get key store path for fluent API



53
54
55
56
57
58
59
60
# File 'lib/vertx/ssl_support.rb', line 53

def key_store_path(path = nil)
  if path
    @j_del.setKeyStorePath(path)
    self
  else
    @j_del.getKeyStorePath
  end
end

#key_store_path=(val) ⇒ Object

Set the path to the SSL key store. This method should only be used with the client/server in SSL mode, i.e. after #ssl= has been set to true. The SSL key store is a standard Java Key Store, and should contain the client/server certificate. For a client, it’s only necessary to supply a client key store if the server requires client authentication via client certificates.

Parameters:

  • val. (String)

    The path to the key store

Returns:

  • self. So multiple invocations can be chained.



47
48
49
50
# File 'lib/vertx/ssl_support.rb', line 47

def key_store_path=(val)
  @j_del.setKeyStorePath(val)
  self
end

#ssl(ssl = nil) ⇒ Object

Set or get ssl for fluent API



32
33
34
35
36
37
38
39
# File 'lib/vertx/ssl_support.rb', line 32

def ssl(ssl = nil)
  if ssl
    @j_del.setSSL(ssl)
    self
  else
    @j_del.isSSL
  end
end

#ssl=(val) ⇒ Object

Set whether the server or client will use SSL.

Parameters:

  • val. (Boolean)

    If true then ssl will be used.

Returns:

  • self. So multiple invocations can be chained.



26
27
28
29
# File 'lib/vertx/ssl_support.rb', line 26

def ssl=(val)
  @j_del.setSSL(val)
  self
end

#trust_store_password(password = nil) ⇒ Object

Set or get trust store password for fluent API



113
114
115
116
117
118
119
120
# File 'lib/vertx/ssl_support.rb', line 113

def trust_store_password(password = nil)
  if password
    @j_del.setTrustStorePassword(password)
    self
  else
    @j_del.getTrustStorePassword
  end
end

#trust_store_password=(val) ⇒ Object

Set the password for the SSL trust store. This method should only be used with the client in SSL mode, i.e. after #ssl= has been set to true.

Parameters:

  • val. (String)

    The password.

Returns:

  • self. So multiple invocations can be chained.



107
108
109
110
# File 'lib/vertx/ssl_support.rb', line 107

def trust_store_password=(val)
  @j_del.setTrustStorePassword(val)
  self
end

#trust_store_path(path = nil) ⇒ Object

Set or get trust store path for fluent API



94
95
96
97
98
99
100
101
# File 'lib/vertx/ssl_support.rb', line 94

def trust_store_path(path = nil)
  if path
    @j_del.setTrustStorePath(path)
    self
  else
    @j_del.getTrustStorePath
  end
end

#trust_store_path=(val) ⇒ Object

Set the path to the SSL trust store. This method should only be used with the client/server in SSL mode, i.e. after #ssl= has been set to true. The SSL trust store is a standard Java Key Store, and should contain the certificate(s) of the clients/servers that the server/client trusts. The SSL handshake will fail if the server provides a certificate that the client does not trust, or if client authentication is used, if the client provides a certificate the server does not trust.<p>

Parameters:

  • val. (String)

    The path to the trust store

Returns:

  • self. So multiple invocations can be chained.



88
89
90
91
# File 'lib/vertx/ssl_support.rb', line 88

def trust_store_path=(val)
  @j_del.setTrustStorePath(val)
  self
end